Module signals

Module signals 

This module contains functions to handle signals.

Structs

Started
This is the message that the “launcher” spawned task sends to the main application process to notify the service was successfully started.

Enums

Halted
This is the message that the “launcher” spawned task receives from the main application process to notify the service to shutdown.

Functions

global_shutdown_signal
Resolves on ctrl_c or the terminate signal.
shutdown_signal
Resolves when the stop_receiver or the global_shutdown_signal() resolves.
shutdown_signal_with_message
Same as shutdown_signal(), but shows a message when it resolves.